@@ -1,12 +1,11 @@
+from typing import Dict, List
 from rich.console import Console
 from rich.panel import Panel
 from rich.table import Table
 from orionis.console.base.command import BaseCommand
 from orionis.console.contracts.schedule import ISchedule
 from orionis.console.exceptions import CLIOrionisRuntimeError
-from orionis.container.exceptions.exception import OrionisContainerException
 from orionis.foundation.contracts.application import IApplication
-from orionis.foundation.exceptions.runtime import OrionisRuntimeError
 
 class ScheduleListCommand(BaseCommand):
     """
@@ -38,7 +37,7 @@ class ScheduleListCommand(BaseCommand):
     # Command description
     description: str = "Executes the scheduled tasks defined in the application."
 
-    def handle(self, app: IApplication, console: Console) -> bool:
+    async def handle(self, app: IApplication, console: Console) -> bool:
         """
         Displays a table of scheduled jobs defined in the application.
 
@@ -64,16 +63,16 @@ class ScheduleListCommand(BaseCommand):
         try:
 
             # Retrieve the Scheduler instance from the application
-            Scheduler = app.getScheduler()
+            scheduler = app.getScheduler()
 
             # Create an instance of the ISchedule service
             schedule_service: ISchedule = app.make(ISchedule)
 
             # Register scheduled tasks using the Scheduler's tasks method
-            Scheduler.tasks(schedule_service)
+            await scheduler.tasks(schedule_service)
 
             # Retrieve the list of scheduled jobs/events
-            list_tasks = schedule_service.events()
+            list_tasks: List[Dict] = schedule_service.events()
 
             # Display a message if no scheduled jobs are found
             if not list_tasks:
@@ -87,20 +86,20 @@ class ScheduleListCommand(BaseCommand):
             table.add_column("Signature", style="cyan", no_wrap=True)
             table.add_column("Arguments", style="magenta")
             table.add_column("Purpose", style="green")
-            table.add_column("Random Delay (calculated result)", style="yellow")
+            table.add_column("Random Delay (Calculated Result)", style="yellow")
             table.add_column("Start Date", style="white")
             table.add_column("End Date", style="white")
             table.add_column("Details", style="dim")
 
             # Populate the table with job details
             for job in list_tasks:
-                signature = str(job.get("signature", ""))
-                args = ", ".join(map(str, job.get("args", [])))
-                purpose = str(job.get("purpose", ""))
-                random_delay = str(job.get("random_delay", ""))
-                start_date = str(job.get("start_date", "")) if job.get("start_date") else "-"
-                end_date = str(job.get("end_date", "")) if job.get("end_date") else "-"
-                details = str(job.get("details", ""))
+                signature = str(job.get("signature"))
+                args = str(job.get("args", []))
+                purpose = str(job.get("purpose"))
+                random_delay = str(job.get("random_delay"))
+                start_date = str(job.get("start_date"))
+                end_date = str(job.get("end_date"))
+                details = str(job.get("details"))
 
                 table.add_row(signature, args, purpose, random_delay, start_date, end_date, details)
 
@@ -112,10 +111,6 @@ class ScheduleListCommand(BaseCommand):
 
         except Exception as e:
 
-            # If the exception is already a CLIOrionisRuntimeError or OrionisContainerException, re-raise it
-            if isinstance(e, (OrionisRuntimeError, OrionisContainerException)):
-                raise
-
             # Catch any unexpected exceptions and raise as a CLIOrionisRuntimeError
             raise CLIOrionisRuntimeError(
                 f"An unexpected error occurred while listing the scheduled jobs: {e}"
