@@ -1,17 +1,17 @@
 import argparse
 import os
+from pathlib import Path
 import re
 from typing import Any, List, Optional
 from orionis.console.args.argument import CLIArgument
 from orionis.console.base.command import BaseCommand
-from orionis.console.base.contracts.command import IBaseCommand
+from orionis.console.contracts.command import IBaseCommand
 from orionis.console.contracts.reactor import IReactor
 from orionis.console.enums.command import Command
 from orionis.console.exceptions import CLIOrionisValueError
 from orionis.console.exceptions.cli_runtime_error import CLIOrionisRuntimeError
 from orionis.console.output.contracts.console import IConsole
 from orionis.console.output.contracts.executor import IExecutor
-from orionis.container.exceptions.exception import OrionisContainerException
 from orionis.foundation.contracts.application import IApplication
 from orionis.services.introspection.modules.reflection import ReflectionModule
 from orionis.services.log.contracts.log_service import ILogger
@@ -65,7 +65,8 @@ class Reactor(IReactor):
         self.__commands: dict[str, Command] = {}
 
         # Automatically discover and load command classes from the console commands directory
-        self.__loadCommands(self.__app.path('commands'), self.__root)
+        cli_commands_path = (Path(self.__app.path('console')) / 'commands').resolve()
+        self.__loadCommands(cli_commands_path, self.__root)
 
         # Load core command classes provided by the Orionis framework
         self.__loadCoreCommands()
@@ -401,10 +402,13 @@ class Reactor(IReactor):
 
         # Create an ArgumentParser instance to handle the command arguments
         arg_parser = argparse.ArgumentParser(
-            description=f"{obj.signature} - {obj.description}",
-            formatter_class=argparse.RawDescriptionHelpFormatter,
+            usage=f"python -B reactor {obj.signature} [options]",
+            description=f"Command [{obj.signature}] : {obj.description}",
+            formatter_class=argparse.RawTextHelpFormatter,
             add_help=True,
-            allow_abbrev=False
+            allow_abbrev=False,
+            exit_on_error=True,
+            prog=obj.signature
         )
         for arg in required_args:
             arg.addToParser(arg_parser)
@@ -455,8 +459,12 @@ class Reactor(IReactor):
                 # Parse the provided arguments using the command's ArgumentParser
                 parsed_args = command.args.parse_args(args)
             except SystemExit:
-                # Allow argparse to handle help/error messages and exit
-                raise
+                # Raise a CLIOrionisRuntimeError with the help message included in the exception
+                raise CLIOrionisRuntimeError(
+                    f"Failed to parse arguments for command '{command.signature}'.\n"
+                    f"{command.args.format_help()}\n"
+                    "Please check the command syntax and available options."
+                )
 
         # Convert the parsed arguments to a dictionary and return
         if isinstance(parsed_args, argparse.Namespace):
@@ -583,12 +591,6 @@ class Reactor(IReactor):
 
         except Exception as e:
 
-            # Display the error message in the console (without timestamp)
-            if isinstance(e, OrionisContainerException):
-                pass
-            elif isinstance(e, CLIOrionisRuntimeError):
-                self.__console.error(f"An error occurred while executing command '{signature}': {e}", timestamp=False)
-
             # Log the error in the logger service
             self.__logger.error(f"Command '{signature}' execution failed: {e}")
 
@@ -677,9 +679,6 @@ class Reactor(IReactor):
 
         except Exception as e:
 
-            # Display the error message in the console (without timestamp)
-            self.__console.error(f"An error occurred while executing command '{signature}': {e}", timestamp=False)
-
             # Log the error in the logger service
             self.__logger.error(f"Command '{signature}' execution failed: {e}")
 
