@@ -37,16 +37,16 @@ class Directory(IDirectory):
         """
         return Path(self.__app.path('root'))
 
-    def commands(self) -> Path:
+    def console(self) -> Path:
         """
-        Get the commands directory path.
+        Get the console directory path.
 
         Returns
         -------
         Path
-            The path to the commands directory.
+            The path to the console directory.
         """
-        return Path(self.__app.path('commands'))
+        return Path(self.__app.path('console'))
 
     def controllers(self) -> Path:
         """
